@@ -9,9 +9,6 @@ OC.L10N.register(
     "Save" : "Save",
     "Loading documents..." : "Loading documents...",
     "Edit" : "Edit",
-    "Document" : "Document",
-    "Spreadsheet" : "Spreadsheet",
-    "Presentation" : "Presentation",
     "Could not create file" : "Could not create file",
     "New Document.odt" : "New Document.odt",
     "New Spreadsheet.ods" : "New Spreadsheet.ods",
